﻿using Microsoft.Practices.Prism.MefExtensions;
using System.Windows;
using System.ComponentModel.Composition;
using System.ComponentModel.Composition.Hosting;
using DataBrowser.Modules;
using Microsoft.Practices.Prism.Regions;
using Infragistics.Windows.Ribbon;
using DataBrowser.Infrastructure;
using Microsoft.Practices.ServiceLocation;
using DataBrowser.Views;
using DataBrowser.ViewModel;
using Infragistics.Windows.DockManager;

namespace DataBrowser.App
{
    public class DataBrowserBootStrapper : MefBootstrapper
    {
        private CompositionContainer _container;

        protected override DependencyObject CreateShell()
        {
            var shell = this.Container.GetExportedValue<Shell>();
            return shell;
        }

        protected override void InitializeShell()
        {
            base.InitializeShell();

            Application.Current.MainWindow = (Window)this.Shell;
            Application.Current.MainWindow.Show();
        }

        protected override void ConfigureAggregateCatalog()
        {
            base.ConfigureAggregateCatalog();

            // Add this assembly to export ModuleTracker
            this.AggregateCatalog.Catalogs.Add(new AssemblyCatalog(typeof(DataBrowserBootStrapper).Assembly));
            this.AggregateCatalog.Catalogs.Add(new AssemblyCatalog(typeof(MainModule).Assembly));
            this.AggregateCatalog.Catalogs.Add(new AssemblyCatalog(typeof(DefaultMenuView).Assembly));
            this.AggregateCatalog.Catalogs.Add(new AssemblyCatalog(typeof(CompositeViewModel).Assembly));
            this.AggregateCatalog.Catalogs.Add(new AssemblyCatalog(typeof(XamRibbonRegionAdapter).Assembly));
            _container = new CompositionContainer(this.AggregateCatalog);
            CompositionBatch batch = new CompositionBatch();
            batch.AddExportedValue(_container);
            _container.Compose(batch);
        }

        protected override RegionAdapterMappings ConfigureRegionAdapterMappings()
        {
            RegionAdapterMappings regionAdapterMappings = base.ConfigureRegionAdapterMappings();            
            regionAdapterMappings.RegisterMapping(typeof(XamRibbon), ServiceLocator.Current.GetInstance<XamRibbonRegionAdapter>());
            regionAdapterMappings.RegisterMapping(typeof(TabGroupPane), ServiceLocator.Current.GetInstance<TabGroupePaneRegionAdapter>());            
            return regionAdapterMappings;
        }
    }
}
