﻿using System;
using System.Linq;
using Microsoft.Practices.Prism.Regions;
using Infragistics.Windows.DockManager;
using System.ComponentModel.Composition;
using Microsoft.Practices.ServiceLocation;

namespace DataBrowser.Infrastructure
{
    /// <summary>
    /// RegionAdapter for TabGroupPane.
    /// </summary>
    [Export(typeof(TabGroupePaneRegionAdapter))]
    public class TabGroupePaneRegionAdapter : RegionAdapterBase<TabGroupPane>
    {
        #region Private Members.
      
        private IRegionManager _regionManager;

        #endregion Private Members.

        #region Ctor.       
      
        [ImportingConstructor]
        public TabGroupePaneRegionAdapter(IRegionBehaviorFactory regionBehaviorFactory)
            : base(regionBehaviorFactory)
        {
            _regionManager = ServiceLocator.Current.GetInstance<IRegionManager>();           
        }

        #endregion Ctor.

        #region Overrides.

        protected override void Adapt(IRegion region, TabGroupPane regionTarget)
        {
            //Adding the region to RegionManager to handle region specific activities in RawFileTabViewModel.
            if (!_regionManager.Regions.ContainsRegionWithName(region.Name))
            {
                _regionManager.Regions.Add(region);
                try
                {
                    //Add item to the TabGroupPane.
                    AddItems(region, regionTarget);

                    //Activate the recently added Item.
                    ActivateView(region, regionTarget);
                }
                catch(Exception ex)
                {
                    
                }
            }
        }

        protected override IRegion CreateRegion()
        {
            return new Region();
        }

        #endregion Overrides.

        #region Methods.
        
        private static void ActivateView(IRegion region, TabGroupPane regionTarget)
        {          
            region.Views.CollectionChanged += (sender, e) =>
            {
                //Activate the view.
                if (e.Action == System.Collections.Specialized.NotifyCollectionChangedAction.Add)
                {
                    if (e.NewItems[0] != null)
                    {
                        region.Activate(e.NewItems[0]);
                    }
                }               
            };
        }
        private static int count=1;
        private void AddItems(IRegion region, TabGroupPane regionTarget)
        {            
            region.ActiveViews.CollectionChanged += (sender, e) =>
            {
                if (e.NewItems == null)
                    return;
                ContentPane pane = new ContentPane();
                var view = region.ActiveViews.LastOrDefault();                
                if (view != null)
                {
                    pane.Content = view;                    
                    pane.Header = "Test"+count;
                    pane.AllowDockingFloating = false;
                    regionTarget.Items.Add(pane);
                    pane.BringIntoView();
                }
                count++;
            };
        }
        #endregion Methods.    
    }
}
