﻿using System.Collections.Generic;
using System.Linq;
using Infragistics.Windows.Ribbon;
using Microsoft.Practices.Prism.Regions;
using System.Collections.Specialized;
using System.ComponentModel.Composition;

namespace DataBrowser.Infrastructure
{
    /// <summary>
    /// RegionAdapter for XamRibbon.
    /// </summary>
    [Export(typeof(XamRibbonRegionAdapter))]
    public class XamRibbonRegionAdapter : RegionAdapterBase<XamRibbon>
    {
        #region Private Members.

        private XamRibbon _xamRibbonRegionTarget = null;

        #endregion Private Members.

        #region Ctor.

        /// <summary>
        /// Initialize the base class with IRegionBehaviorFactory
        /// </summary>
        /// <param name="regionBehaviorFactory"></param>
        [ImportingConstructor]
        public XamRibbonRegionAdapter(IRegionBehaviorFactory regionBehaviorFactory)
            : base(regionBehaviorFactory)
        { }

        #endregion Ctor.

        #region Overrides

        protected override void Adapt(IRegion region, XamRibbon regionTarget)
        {
            this._xamRibbonRegionTarget = regionTarget;

            if (this._xamRibbonRegionTarget.Tabs.Count > 0)
            {
                foreach (object tab in this._xamRibbonRegionTarget.Tabs)
                {
                    region.Add(tab);
                }

                this._xamRibbonRegionTarget.Tabs.Clear();
            }

            if (this._xamRibbonRegionTarget.ContextualTabGroups.Count > 0)
            {
                foreach (object tabGroup in this._xamRibbonRegionTarget.ContextualTabGroups)
                {
                    region.Add(tabGroup);
                }

                this._xamRibbonRegionTarget.ContextualTabGroups.Clear();
            }

            foreach (object view in region.Views)
            {
                AddViewToRegion(view, this._xamRibbonRegionTarget);
            }

            region.ActiveViews.CollectionChanged += (s, args) =>
            {
                switch (args.Action)
                {
                    case NotifyCollectionChangedAction.Add:
                        {
                            foreach (object view in args.NewItems)
                            {
                                AddViewToRegion(view, this._xamRibbonRegionTarget);
                            }
                            break;
                        }
                    case NotifyCollectionChangedAction.Remove:
                        {
                            foreach (object view in args.OldItems)
                            {
                                RemoveViewFromRegion(view, this._xamRibbonRegionTarget);
                            }
                            break;
                        }
                    default:
                        {
                            // Do nothing.
                            break;
                        }
                }
            };
        }

        protected override IRegion CreateRegion()
        {
            return new AllActiveRegion();
        }

        #endregion Overrides

        #region Private

        private void AddViewToRegion(object view, XamRibbon xamRibbon)
        {
            RibbonTabItem ribbonTabItem = view as RibbonTabItem;
            if (ribbonTabItem != null)
            {
                xamRibbon.Tabs.Add(ribbonTabItem);
            }
            else
            {
                ContextualTabGroup contextualTabGroup = view as ContextualTabGroup;
                if (contextualTabGroup != null)
                {
                    xamRibbon.ContextualTabGroups.Add(contextualTabGroup);
                }
            }
        }

        private void RemoveViewFromRegion(object view, XamRibbon xamRibbon)
        {
            RibbonTabItem ribbonTabItem = view as RibbonTabItem;
            if (ribbonTabItem != null)
            {
                xamRibbon.Tabs.Remove(ribbonTabItem);
            }
            else
            {
                ContextualTabGroup contextualTabGroup = view as ContextualTabGroup;
                if (contextualTabGroup != null)
                {
                    xamRibbon.ContextualTabGroups.Remove(contextualTabGroup);
                }
            }
        }

        #endregion Private
    }
}

