﻿using System.ComponentModel.Composition;
using Microsoft.Practices.Prism.Commands;
using Microsoft.Practices.Prism.Events;
using Microsoft.Practices.Prism.Modularity;
using Microsoft.Practices.ServiceLocation;
using DataBrowser.IAppControllers;
using DataBrowser.Infrastructure;
using System.Windows;

namespace DataBrowser.ViewModel
{
    /// <summary>
    /// MenuModuleController to handles the Commands and actions of DefaultMenuViewModel.
    /// </summary>
    [Export(typeof(IDefaultMenuControler))]
    public class DefaultMenuController : IDefaultMenuControler
    {        
        private IServiceLocator _locator;
        private bool _isModuleLoaded;

        #region Constructor.

        /// <summary>
        /// Default constructor to initialize the instances.
        /// </summary>
        public DefaultMenuController()
        {
            _locator = ServiceLocator.Current;           
            OpenFileCommand = new DelegateCommand(OpenFileMethod);
            CloseCommand = new DelegateCommand(CloseFile);            
           
        }

        #endregion Constructor.

        #region Commands.

        /// <summary>
        /// Delegate command for Open File.
        /// </summary>
        public DelegateCommand OpenFileCommand { get; private set; }

        /// <summary>
        /// Delegate command for close the current view and raw files.
        /// </summary>
        public DelegateCommand CloseCommand { get; private set; }
     

        #endregion Commands.

        #region Public Methods.

        /// <summary>
        /// Opens the raw file.
        /// </summary>
        public void OpenFileMethod()
        {
            //Loading on Demand
            if (!_isModuleLoaded) //don't want to load the modules in every file open.
            {
                _locator.GetInstance<IModuleManager>().LoadModule("MainModule");
                _isModuleLoaded = true;
            }
            _locator.GetInstance<IEventAggregator>().GetEvent<LoadFile>().Publish(string.Empty);
            
        }
        
        public void CloseFile()
        {
            Application.Current.Shutdown();
        }

        
        #endregion Public Methods.
    }
}
